@@ -686,12 +686,16 @@ class ProcVmas:
         if pid is None:
             return
 
-        with open('/proc/%s/maps' % pid, 'r') as f:
-            for line in f:
-                fields = line.split()
-                start, end = [int(addr, 16) for addr in fields[0].split('-')]
-                name = fields[-1]
-                self.vmas.append(Vma(start, end, name))
+        try:
+            with open('/proc/%s/maps' % pid, 'r') as f:
+                for line in f:
+                    fields = line.split()
+                    start, end = [int(addr, 16) for addr in fields[0].split('-')]
+                    name = fields[-1]
+                    self.vmas.append(Vma(start, end, name))
+        except:
+            # the process may terminated.
+            return
 
     def to_kvpairs(self):
         kvpairs = {'pid': self.pid}
@@ -749,6 +753,92 @@ def load_proc_vmas(filepath):
         kvpairs = json.load(f)
     return [ProcVmasSnapshot.from_kvpairs(x) for x in kvpairs]
 
+class ProcStat:
+    pid = None
+    tcomm = None
+    state = None
+    utime = None
+    stime = None
+
+    def __init__(self, pid):
+        if pid is None:
+            return
+        try:
+            with open('/proc/%s/stat' % pid, 'r') as f:
+                fields = f.read().split()
+                self.pid = pid
+                self.tcomm = fields[1]
+                self.state = fields[2]
+                self.utime = fields[13]
+                self.stime = fields[14]
+        except Exception:
+            # the process may finished already
+            pass
+
+    def to_kvpairs(self):
+        return {
+                'pid': self.pid,
+                'tcomm': self.tcomm,
+                'state': self.state,
+                'utime': self.utime,
+                'stime': self.stime,
+                }
+
+    @classmethod
+    def from_kvpairs(cls, kvpairs):
+        self = cls(None)
+        self.pid = kvpairs['pid']
+        self.tcomm = kvpairs['tcomm']
+        self.state = kvpairs['state']
+        self.utime = kvpairs['utime']
+        self.stime = kvpairs['stime']
+
+class ProcStatsSnapshot:
+    time = None
+    proc_stats = None
+
+    def __init__(self, pids):
+        if pids is None:
+            return
+
+        self.time = time.time()
+        self.proc_stats = []
+        for pid in pids:
+            self.proc_stats.append(ProcStat(pid))
+
+    def to_kvpairs(self):
+        kvpairs = {'time': self.time}
+        kvpairs['proc_stats'] = [p.to_kvpairs() for p in self.proc_stats]
+        return kvpairs
+
+    @classmethod
+    def from_kvpairs(cls, kvpairs):
+        self = cls(None)
+        self.time = kvpairs['time']
+        self.proc_stats = [ProcStat.from_kvpairs(kvp)
+                         for kvp in kvapirs['proc_stats']]
+
+def record_proc_stats(kdamonds, snapshots):
+    pids = []
+    for kdamond in kdamonds:
+        pids.append(kdamond.pid)
+        for ctx in kdamond.contexts:
+            for target in ctx.targets:
+                if target.pid is None:
+                    continue
+                pids.append(target.pid)
+    snapshots.append(ProcStatsSnapshot(pids))
+
+def save_proc_stats(snapshots, filepath, file_permission):
+    with open(filepath, 'w') as f:
+        json.dump([s.to_kvpairs() for s in snapshots], f, indent=4)
+    os.chmod(filepath, file_permission)
+
+def load_proc_stats(filepath):
+    with open(filepath, 'r') as f:
+        kvpairs = json.load(f)
+    return [ProcStatsSnapshot.from_kvpairs(x) for x in kvpairs]
+
 def add_childs_target(kdamonds):
     current_targets = kdamonds[0].contexts[0].targets
 
@@ -833,11 +923,16 @@ class RecordingHandle:
     # for vmas recording
     vmas_snapshots = None
 
+    # for /proc/<pid>/stat recording
+    proc_stats = None
+
+    timeout = None
+
     def __init__(self, tracepoint, file_path, file_format, file_permission,
                  monitoring_intervals,
                  do_profile,
                  kdamonds, add_child_tasks, record_mem_footprint,
-                 record_vmas=False):
+                 record_vmas, timeout):
         self.tracepoint = tracepoint
         self.file_path = file_path
         self.file_format = file_format
@@ -853,6 +948,10 @@ class RecordingHandle:
         if record_vmas is True:
             self.vmas_snapshots = []
 
+        self.proc_stats = []
+
+        self.timeout = timeout
+
 def start_recording(handle):
     if handle.tracepoint is not None:
         handle.perf_pipe = subprocess.Popen(
@@ -861,6 +960,8 @@ def start_recording(handle):
     if handle.do_profile:
         cmd = [PERF, 'record', '-o', '%s.profile' % handle.file_path]
         handle.perf_profile_pipe = subprocess.Popen(cmd)
+
+    start_time = time.time()
     while (poll_target_pids(handle.kdamonds) or
            _damon.any_kdamond_running()):
         if handle.add_child_tasks is True:
@@ -871,6 +972,11 @@ def start_recording(handle):
                                  handle.mem_footprint_snapshots)
         if handle.vmas_snapshots is not None:
             record_proc_vmas(handle.kdamonds, handle.vmas_snapshots)
+
+        record_proc_stats(handle.kdamonds, handle.proc_stats)
+        if (handle.timeout is not None and
+            time.time() - start_time >= handle.timeout):
+            break
         time.sleep(1)
 
 def finish_recording(handle):
@@ -905,6 +1011,8 @@ def finish_recording(handle):
     if handle.vmas_snapshots is not None:
         save_proc_vmas(handle.vmas_snapshots, '%s.vmas' % handle.file_path,
                        handle.file_permission)
+    save_proc_stats(handle.proc_stats, '%s.proc_stats' % handle.file_path,
+                    handle.file_permission)
 
 # for snapshot
 
@@ -1214,6 +1322,26 @@ class RecordFilter:
         self.address_ranges = address_ranges
         self.snapshot_sz_ranges = snapshot_sz_ranges
 
+    def to_kvpairs(self, raw):
+        kvpairs = {'access_pattern': self.access_pattern.to_kvpairs(raw)}
+        if self.address_ranges is None:
+            address_ranges = None
+        else:
+            address_ranges = [
+                    [_damo_fmt_str.format_sz(start, raw),
+                     _damo_fmt_str.format_sz(end, raw)]
+                    for start, end in self.address_ranges]
+        kvpairs['address_ranges'] = address_ranges
+        if self.snapshot_sz_ranges is None:
+            snapshot_sz_ranges = None
+        else:
+            snapshot_sz_ranges = [
+                    [_damo_fmt_str.format_sz(start, raw),
+                     _damo_fmt_str.format_sz(end, raw)]
+                    for start, end in self.snapshot_sz_ranges]
+        kvpairs['snapshot_sz_ranges'] = snapshot_sz_ranges
+        return kvpairs
+
 class RecordGetRequest:
     # TODO: Extend to be used for recording
 
