@@ -635,16 +635,17 @@ def set_argparser(parser, add_record_options):
     set_damos_argparser(parser)
     parser.add_argument('-c', '--schemes', metavar='<json string or file>',
 	    help='data access monitoring-based operation schemes')
-    parser.add_argument('--kdamonds', metavar='<json string or file>',
-            help='json format kdamonds specification to run DAMON for')
+    parser.add_argument('--kdamonds', metavar='<json/yaml string or file>',
+            help=' '.join([
+                'json or yaml format kdamonds specification to run DAMON for.',
+                '\'damo args damon\' can help generating it.']))
     parser.add_argument(
             'deducible_target', type=str, metavar='<deducible string>',
             nargs='?',
             help=' '.join([
                 'The implicit monitoring requests.',
                 'It could be a command, process id, special keywords, or full',
-                'DAMON parameters.  For the full DAMON parameters, json and',
-                'yaml format are supported.']))
+                'DAMON parameters (same to that for --kdamonds)']))
     if add_record_options:
         parser.add_argument('-o', '--out', metavar='<file path>', type=str,
                 default='damon.data', help='output file path')
