@@ -10,6 +10,7 @@ import sys
 
 import _damo_subcmds
 import damo_adjust
+import damo_args
 import damo_convert_record_format
 import damo_diagnose
 import damo_features
@@ -29,6 +30,7 @@ import damo_stop
 import damo_tune
 import damo_validate
 import damo_version
+import damo_read
 
 def pr_damo_version(args_not_use):
     print(damo_version.__version__)
@@ -68,7 +70,9 @@ subcmds = [
             module=_damo_subcmds.DamoSubCmdModule(None, pr_damo_version),
             msg='print the version number'),
         _damo_subcmds.DamoSubCmd(name='fmt_json', module=damo_fmt_json,
-            msg='convert damo-start cmdline option to DAMON json input'),
+            msg=' '.join(
+                ['(WILL BE DEPRECATED)',
+                 'convert damo-start cmdline option to DAMON json input'])),
         _damo_subcmds.DamoSubCmd(name='schemes', module=damo_schemes,
             msg='apply operation schemes'),
         _damo_subcmds.DamoSubCmd(name='monitor', module=damo_monitor,
@@ -88,13 +92,27 @@ subcmds = [
         _damo_subcmds.DamoSubCmd(name='diagnose',
             module=damo_diagnose,
             msg='generate a report on if DAMON is malfunctioning'),
+        _damo_subcmds.DamoSubCmd(name='read',
+            module=damo_read,
+            msg='(EXPERIMENTAL) read DAMON/system results and status'),
+        _damo_subcmds.DamoSubCmd(name='args',
+            module=damo_args,
+            msg='(EXPERIMENTAL) generate complex arguments for other commands')
+
         ]
 
 class SubCmdHelpFormatter(argparse.RawDescriptionHelpFormatter):
     def _format_action(self, action):
         parts = super(argparse.RawDescriptionHelpFormatter,
                 self)._format_action(action)
-        # skip sub parsers help
+        # by default, the help message shows command metavar, like below.  Hide
+        # it.
+        #
+        # $ ./damo -h
+        # [...]
+        # command:
+        #   <command>  # <- This looks weird
+        #     start               start DAMON with given parameters
         if action.nargs == argparse.PARSER:
             parts = '\n'.join(parts.split('\n')[1:])
         return parts
